import { Component, ElementRef, EventEmitter, HostListener, Input, Output, ViewChild } from '@angular/core';
import { BsDropdownDirective } from 'ngx-bootstrap/dropdown';
var DatetimePopupComponent = /** @class */ (function () {
    function DatetimePopupComponent(elementRef) {
        this.elementRef = elementRef;
        this.appendTo = undefined;
        this.valueChange = new EventEmitter();
        this.showPopup = false;
        this.showPopupChange = new EventEmitter();
        this.showDate = true;
        this.showTime = true;
        this.showWeeks = false;
        this.datepickerMode = 'day';
        this.initDate = null;
        this.minDate = null;
        this.maxDate = null;
        this.dateDisabled = [];
        this.localValue = null;
        this.isOpening = false;
        this.isDropUp = false;
    }
    DatetimePopupComponent.prototype.ngOnChanges = function (changes) {
        if (!this.nowButton) {
            this.nowButton = { show: true, label: 'Now', cssClass: 'btn btn-secondary btn-sm' };
        }
        if (!this.clearButton) {
            this.clearButton = { show: true, label: 'Clear', cssClass: 'btn btn-secondary btn-sm' };
        }
        if (!this.closeButton) {
            this.closeButton = { show: true, label: 'Close', cssClass: 'btn btn-secondary btn-sm' };
        }
        // user maybe typing a value into an input box, so would come in as string
        if (typeof this.value === 'string') {
            // check if the string is a valid date
            if (!isNaN(new Date(this.value).getTime())) {
                this.localValue = new Date(this.value);
            }
        }
        else if (this.value) {
            this.localValue = this.value;
        }
        // toggle if open
        if (changes.showPopup) {
            if (changes.showPopup.currentValue === true) {
                this.showPopup = true;
            }
            else {
                this.showPopup = false;
            }
        }
    };
    DatetimePopupComponent.prototype.onWindowScroll = function () {
        var nativeEl = this.elementRef.nativeElement;
        var clientRect = nativeEl.getBoundingClientRect();
        var scrollTop = document.documentElement.scrollTop || document.body.scrollTop;
        var offsetTop = clientRect.top + window.pageYOffset;
        var height = clientRect.height;
        var dropdownEl = nativeEl.children.item(0);
        var menuEl = dropdownEl.children.item(0);
        // get the style
        var display = menuEl.style.display;
        menuEl.style.display = 'block';
        var menuHeight = menuEl.getBoundingClientRect().height;
        menuEl.style.display = display;
        this.isDropUp = (offsetTop + height + menuHeight > scrollTop + document.documentElement.clientHeight);
    };
    DatetimePopupComponent.prototype.onOpenChange = function () {
        var _this = this;
        this.isOpening = true;
        setTimeout(function () { return _this.isOpening = false; }, 250);
    };
    DatetimePopupComponent.prototype.onHidden = function () {
        this.showPopup = false;
        this.showPopupChange.emit(false);
    };
    DatetimePopupComponent.prototype.onNow = function () {
        this.localValue = new Date();
        this.onPickerChange();
    };
    DatetimePopupComponent.prototype.onClear = function () {
        this.valueChange.emit(null);
    };
    DatetimePopupComponent.prototype.onClose = function () {
        this.showPopup = false;
        this.showPopupChange.emit(false);
    };
    DatetimePopupComponent.prototype.onPickerChange = function () {
        if (this.isOpening === true) {
            return;
        }
        this.valueChange.emit(this.localValue);
        if (this.showDate === true && this.showTime === false) {
            this.onHidden();
        }
    };
    DatetimePopupComponent.decorators = [
        { type: Component, args: [{
                    selector: 'datetime-popup',
                    template: "\n    <div dropdown #dropdown=\"bs-dropdown\" [container]=\"appendTo\" (isOpenChange)=\"onOpenChange()\" (onHidden)=\"onHidden()\" [dropup]=\"isDropUp\">\n      <ul class=\"datetime-popup dropdown-menu\" role=\"menu\" (offClick)=\"onClose()\" [ngClass]=\"{ 'show': showPopup === true }\">\n        <li class=\"my-2 mx-2\">\n          <datepicker *ngIf=\"showDate\"\n                      [(ngModel)]=\"localValue\"\n                      (ngModelChange)=\"onPickerChange()\"\n                      [showWeeks]=\"showWeeks\"\n                      [datepickerMode]=\"datepickerMode\"\n                      [minDate]=\"minDate\"\n                      [maxDate]=\"maxDate\"\n                      [dateDisabled]=\"dateDisabled\"></datepicker>\n          <timepicker *ngIf=\"showTime\"\n                      [(ngModel)]=\"localValue\"\n                      [min]=\"minDate\"\n                      [max]=\"maxDate\"\n                      (ngModelChange)=\"onPickerChange()\"></timepicker>\n        </li>\n        <li class=\"mx-2 mb-2\">\n          <span class=\"btn-group pull-left\">\n              <button type=\"button\"\n                      (click)=\"onNow()\"\n                      *ngIf=\"nowButton.show\"\n                      [ngClass]=\"nowButton.cssClass\">{{ nowButton.label }}</button>\n              <button type=\"button\"\n                      (click)=\"onClear()\"\n                      *ngIf=\"clearButton.show\"\n                      [ngClass]=\"clearButton.cssClass\">{{ clearButton.label }}</button>\n          </span>\n          <span class=\"btn-group pull-right\">\n              <button type=\"button\"\n                      (click)=\"onClose()\"\n                      *ngIf=\"closeButton.show\"\n                      [ngClass]=\"closeButton.cssClass\">{{ closeButton.label }}</button>\n          </span>\n        </li>\n      </ul>\n    </div>\n  "
                },] },
    ];
    /** @nocollapse */
    DatetimePopupComponent.ctorParameters = function () { return [
        { type: ElementRef }
    ]; };
    DatetimePopupComponent.propDecorators = {
        dropdown: [{ type: ViewChild, args: ['dropdown',] }],
        appendTo: [{ type: Input }],
        value: [{ type: Input }],
        valueChange: [{ type: Output }],
        showPopup: [{ type: Input }],
        showPopupChange: [{ type: Output }],
        showDate: [{ type: Input }],
        showTime: [{ type: Input }],
        showWeeks: [{ type: Input }],
        datepickerMode: [{ type: Input }],
        initDate: [{ type: Input }],
        minDate: [{ type: Input }],
        maxDate: [{ type: Input }],
        dateDisabled: [{ type: Input }],
        nowButton: [{ type: Input }],
        clearButton: [{ type: Input }],
        closeButton: [{ type: Input }],
        onWindowScroll: [{ type: HostListener, args: ['window:scroll', [],] }]
    };
    return DatetimePopupComponent;
}());
export { DatetimePopupComponent };
//# sourceMappingURL=datetime-popup.component.js.map